import { Module, Global } from '@nestjs/common';
import { ConfigModule } from '@nestjs/config';
import { Pool } from 'pg';
import { drizzle } from 'drizzle-orm/node-postgres';
import * as schema from './schema';
import { DatabaseService } from './database.service';

export const DATABASE_POOL = 'DATABASE_POOL';
export const DRIZZLE = 'DRIZZLE';

@Global()
@Module({
  imports: [ConfigModule],
  providers: [
    DatabaseService,
    {
      provide: DATABASE_POOL,
      useFactory: (databaseService: DatabaseService) => {
        return databaseService.getPool();
      },
      inject: [DatabaseService],
    },
    {
      provide: DRIZZLE,
      useFactory: (databaseService: DatabaseService) => {
        return databaseService.getDb();
      },
      inject: [DatabaseService],
    },
  ],
  exports: [DatabaseService, DATABASE_POOL, DRIZZLE],
})
export class DatabaseModule {}
