import { relations } from 'drizzle-orm';
import { users } from './users';
import { projects } from './projects';
import { persons } from './persons';
import { groups } from './groups';
import { tags } from './tags';
import { personToGroup } from './personToGroup';
import { personToTag } from './personToTag';
import { projectToTag } from './projectToTag';
import { projectCollaborators } from './projectCollaborators';

/**
 * Define relations for users table
 */
export const usersRelations = relations(users, ({ many }) => ({
  projects: many(projects),
  projectCollaborations: many(projectCollaborators),
}));

/**
 * Define relations for projects table
 */
export const projectsRelations = relations(projects, ({ one, many }) => ({
  owner: one(users, {
    fields: [projects.ownerId],
    references: [users.id],
  }),
  persons: many(persons),
  groups: many(groups),
  projectToTags: many(projectToTag),
  collaborators: many(projectCollaborators),
}));

/**
 * Define relations for persons table
 */
export const personsRelations = relations(persons, ({ one, many }) => ({
  project: one(projects, {
    fields: [persons.projectId],
    references: [projects.id],
  }),
  personToGroups: many(personToGroup),
  personToTags: many(personToTag),
}));

/**
 * Define relations for groups table
 */
export const groupsRelations = relations(groups, ({ one, many }) => ({
  project: one(projects, {
    fields: [groups.projectId],
    references: [projects.id],
  }),
  personToGroups: many(personToGroup),
}));

/**
 * Define relations for tags table
 */
export const tagsRelations = relations(tags, ({ many }) => ({
  personToTags: many(personToTag),
  projectToTags: many(projectToTag),
}));

/**
 * Define relations for personToGroup table
 */
export const personToGroupRelations = relations(personToGroup, ({ one }) => ({
  person: one(persons, {
    fields: [personToGroup.personId],
    references: [persons.id],
  }),
  group: one(groups, {
    fields: [personToGroup.groupId],
    references: [groups.id],
  }),
}));

/**
 * Define relations for personToTag table
 */
export const personToTagRelations = relations(personToTag, ({ one }) => ({
  person: one(persons, {
    fields: [personToTag.personId],
    references: [persons.id],
  }),
  tag: one(tags, {
    fields: [personToTag.tagId],
    references: [tags.id],
  }),
}));

/**
 * Define relations for projectToTag table
 */
export const projectToTagRelations = relations(projectToTag, ({ one }) => ({
  project: one(projects, {
    fields: [projectToTag.projectId],
    references: [projects.id],
  }),
  tag: one(tags, {
    fields: [projectToTag.tagId],
    references: [tags.id],
  }),
}));

/**
 * Define relations for projectCollaborators table
 */
export const projectCollaboratorsRelations = relations(projectCollaborators, ({ one }) => ({
  project: one(projects, {
    fields: [projectCollaborators.projectId],
    references: [projects.id],
  }),
  user: one(users, {
    fields: [projectCollaborators.userId],
    references: [users.id],
  }),
}));
