import { pgTable, uuid, varchar, timestamp, index } from 'drizzle-orm/pg-core';
import { tagType } from './enums';

/**
 * Tags table schema
 */
export const tags = pgTable('tags', {
  id: uuid('id').primaryKey().defaultRandom(),
  name: varchar('name', { length: 50 }).notNull(),
  color: varchar('color', { length: 7 }).notNull(),
  type: tagType('type').notNull(),
  createdAt: timestamp('createdAt', { withTimezone: true }).defaultNow().notNull(),
  updatedAt: timestamp('updatedAt', { withTimezone: true }).defaultNow().notNull()
}, (table) => {
  return {
    nameIdx: index('tag_name_idx').on(table.name),
    typeIdx: index('tag_type_idx').on(table.type)
  };
});

/**
 * Tag type definitions
 */
export type Tag = typeof tags.$inferSelect;
export type NewTag = typeof tags.$inferInsert;
